## Formatted online version of this README
https://www.drupal.org/project/yaml2php

## Convert a YAML snippet to a PHP formatted array  
Conversion form at:\
_admin/config/development/yaml2php_

This is a development helper module to generate a code snippet to copy and paste into your own code. Look at the example at the bottom.

## Use cases

*   Set a certain configuration if certain conditions are met, wrapping it in an `if` statement.
*   Set a certain configuration dynamically, for example, for all available content types, wrapping it in a `foreach` loop.
*   As part of an automated process to set up an environment with certain configuration through PHP after a Drupal bootstrap.

## Usage

Go to the conversion form at _admin/config/development/yaml2php_ (restricted to users with the permission _"Administer site configuration"_). Provide values for the three fields. It is suggested you try some simple configuration first, like the example below.

The snippet can be only a part of a YAML, either from a file or a copy-paste from the database through the interface at _'admin/config/development/configuration/single/export'_. There is **no need to remove preceding whitespace**. Excessive indenting will be removed automatically. Just copy and paste the needed lines as they are. **Leaving the snippet empty will result in the PHP code for the complete configuration object** taken from the YAML file instead of the database.

After form submit, the generated working PHP code snippet (with syntax highlighting) will write the values to the database when executed in your own code. It can be compared with [variable_set in Drupal 7](https://api.drupal.org/comment/62775#comment-62775 "variable_set | bootstrap.inc | Drupal 7.x | Drupal API"). Be aware that in Drupal 8 it should be followed by a [configuration export and commit](https://modulesunraveled.com/drupal-8-composer-and-configuration-management/exporting-config-locally "Exporting Config Locally | Modules Unraveled").

As the last step copy and paste the needed part of the PHP snippet to your own code and test.

## Example

* * *

### INPUT (example)

REPLACE INPUT WITH YOUR OWN CONFIG OBJECT.

#### Configuration object

filter.format.full_html

#### Parent keys

All parent keys from highest to the one above the snippet (here just one):

*   filters

#### YAML snippet
<pre>
      filter_caption:
        id: filter_caption
        provider: filter
        status: true
        weight: 9
        settings: {  }
      filter_htmlcorrector:
        id: filter_htmlcorrector
        provider: filter
        status: true
        weight: 10
        settings: {  }
</pre>
* * *

### OUTPUT (PHP snippet to copy and paste)

```php
    <?php
    /**
     * @file
     * Set part of a configuration object in the database.
     *
     * Remember to export the configuration to coresponding YAML file and commit.
     * Generated with https://drupal.org/project/yaml2php.
     */

    $filter_caption = [
      'id' => 'filter_caption',
      'provider' => 'filter',
      'status' => TRUE,
      'weight' => 9,
      'settings' => [],
    ];
    \Drupal::configFactory()->getEditable('filter.format.full_html')
      ->set('filters.filter_caption', $filter_caption)
      ->save();

    $filter_htmlcorrector = [
      'id' => 'filter_htmlcorrector',
      'provider' => 'filter',
      'status' => TRUE,
      'weight' => 10,
      'settings' => [],
    ];
    \Drupal::configFactory()->getEditable('filter.format.full_html')
      ->set('filters.filter_htmlcorrector', $filter_htmlcorrector)
      ->save();

    ```
